Class: SQLite3::Database::FunctionProxy

Inherits:
Object
  • Object
show all
Defined in:
lib/sqlite3/database.rb

Overview

A helper class for dealing with custom functions (see #create_function, #create_aggregate, and #create_aggregate_handler). It encapsulates the opaque function object that represents the current invocation. It also provides more convenient access to the API functions that operate on the function object.

This class will almost always be instantiated indirectly, by working with the create methods mentioned above.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeFunctionProxy

Create a new FunctionProxy that encapsulates the given func object. If context is non-nil, the functions context will be set to that. If it is non-nil, it must quack like a Hash. If it is nil, then none of the context functions will be available.



773
774
775
776
# File 'lib/sqlite3/database.rb', line 773

def initialize
  @result = nil
  @context = {}
end

Instance Attribute Details

#resultObject

Returns the value of attribute result.



767
768
769
# File 'lib/sqlite3/database.rb', line 767

def result
  @result
end

Instance Method Details

#[](key) ⇒ Object

Returns the value with the given key from the context. This is only available to aggregate functions.



780
781
782
# File 'lib/sqlite3/database.rb', line 780

def [](key)
  @context[key]
end

#[]=(key, value) ⇒ Object

Sets the value with the given key in the context. This is only available to aggregate functions.



786
787
788
# File 'lib/sqlite3/database.rb', line 786

def []=(key, value)
  @context[key] = value
end